@@ -119,10 +119,12 @@ class Pipeline(Generic[R]):
         self.dispatcher.dispatch_to([target_queue])
         return output_pipe
 
-    def batch(self, count: int = 2) -> "Pipeline[Iterable[R]]":
+    def batch(
+        self, count: int = 2, keep_incomplete_batch: bool = True
+    ) -> "Pipeline[Iterable[R]]":
         target_queue: "Queue[R]" = Pipeline.get_new_queue()
         output_pipe: "Pipeline[Iterable[R]]" = Pipeline()
-        p = BatchPipe(target_queue, output_pipe._source, count)
+        p = BatchPipe(target_queue, output_pipe._source, count, keep_incomplete_batch)
         self.dispatcher.dispatch_to([target_queue])
 
         self._register(p, output_pipe)
