@@ -17,6 +17,6 @@ class ExplodePipe(TaskPipe[R, S]):
 
         super().__init__(source, task, target)  # type: ignore
 
-    def dispatch_to_next(self, processed: Iterable[S]):  # type: ignore
+    def _send_to_next(self, processed: Iterable[S]):  # type: ignore
         for p in processed:
-            super().dispatch_to_next(p)
+            super()._send_to_next(p)
