@@ -18,7 +18,7 @@ class ReducePipe(GenericPipe[R, T]):
         self._accumulator = accumulator
         self._reduce_function = reducer
 
-    def perform_task(self, data: R) -> None:  # type: ignore
+    def _perform_task(self, data: R) -> None:  # type: ignore
         self._accumulator = self._reduce_function(data, self._accumulator)
 
     def run(self):
@@ -26,11 +26,13 @@ class ReducePipe(GenericPipe[R, T]):
             try:
                 data = self._source.get(timeout=self._timeout)
                 if GenericPipe.is_death_packet(data):
-                    self.dispatch_to_next(self._accumulator)
+                    self._send_to_next(self._accumulator)
                     self._kill(data)
                     return
-                self.perform_task(data)
+                self._perform_task(data)
             except Exception as e:
+                if str(e.__class__) == "<class '_queue.Empty'>":
+                    continue
                 self._kill(GenericPipe.get_kill_word())
                 print(f"Error_{e.__class__.__name__}_{e.args}")
                 return
